pub enum ParameterDomain {
Real,
Complex,
}Expand description
Differential domain of one ordered operator parameter.
Variants
Real
A real parameter represented by a complex value with zero imaginary part.
Complex
A complex parameter differentiated under the real pairing Re(x†y).