GradientDiagnostics

Struct GradientDiagnostics 

pub struct GradientDiagnostics {
    pub status: GradientStatus,
    pub primal_residual: Option<f64>,
    pub backward_residual: Option<f64>,
    pub spectral_gap: Option<f64>,
    pub primal_applications: usize,
    pub backward_applications: usize,
    pub recomputations: usize,
}
Backend-independent evidence returned with a native derivative.

Fields

status: GradientStatus

Reliability classification.

primal_residual: Option<f64>

Optional primal numerical residual.

backward_residual: Option<f64>

Optional reverse numerical residual.

spectral_gap: Option<f64>

Optional spectral gap or separation diagnostic.

primal_applications: usize

Number of component actions used by the primal/JVP computation.

backward_applications: usize

Number of component actions used by the reverse computation.

recomputations: usize

Number of forward states or actions recomputed by the reverse pass.