pub struct ParameterSchema { /* private fields */ }Expand description
Stable names and differential domains for an ordered parameter vector.
Implementations
Sourceimpl ParameterSchema
impl ParameterSchema
Sourcepub fn new(
names: impl IntoIterator<Item = String>,
domains: impl IntoIterator<Item = ParameterDomain>,
) -> Result<Self>
pub fn new( names: impl IntoIterator<Item = String>, domains: impl IntoIterator<Item = ParameterDomain>, ) -> Result<Self>
Construct a schema after validating names and domain count.
Sourcepub fn for_operator(operator: &QuantumOperator, domain: ParameterDomain) -> Self
pub fn for_operator(operator: &QuantumOperator, domain: ParameterDomain) -> Self
Create a uniform schema from a QuantumOperator’s stable component order.
Sourcepub fn for_operator_with_domains(
operator: &QuantumOperator,
domains: impl IntoIterator<Item = ParameterDomain>,
) -> Result<Self>
pub fn for_operator_with_domains( operator: &QuantumOperator, domains: impl IntoIterator<Item = ParameterDomain>, ) -> Result<Self>
Create a mixed real/complex schema for an operator.
Sourcepub fn domains(&self) -> &[ParameterDomain]
pub fn domains(&self) -> &[ParameterDomain]
Ordered differential domains.