pub struct BosonBasisBuilder { /* private fields */ }Expand description
Builder for a full or fixed-particle bosonic lattice basis.
Implementations
Sourceimpl BosonBasisBuilder
impl BosonBasisBuilder
Sourcepub fn particles(self, particles: usize) -> Self
pub fn particles(self, particles: usize) -> Self
Restrict the basis to a fixed total boson number.
Sourcepub fn particle_sectors(self, sectors: impl IntoIterator<Item = usize>) -> Self
pub fn particle_sectors(self, sectors: impl IntoIterator<Item = usize>) -> Self
Select a union of total boson-occupation sectors.
Sourcepub fn build(self) -> Result<BosonBasis1D>
pub fn build(self) -> Result<BosonBasis1D>
Validate the cutoff and enumerate the requested bosonic sector.