SymmetryOrbit

Struct SymmetryOrbit 

pub struct SymmetryOrbit<State> { /* private fields */ }
Result of reducing one physical state without materializing a basis.

Implementations

Source

impl<State> SymmetryOrbit<State>

pub const fn representative(&self) -> &State

pub const fn orbit_size(&self) -> usize

pub const fn is_compatible(&self) -> bool

pub const fn phase(&self) -> Option<Complex64>

Unit phase of the queried physical state in the representative vector.

pub const fn physical_phase_to_representative(&self) -> Complex64

Physical map phase acquired along the returned generator word.

pub fn generator_word(&self) -> &[usize]

Generator indices applied in order to reach the representative.