UserBasisBuilder

Struct UserBasisBuilder 

pub struct UserBasisBuilder<State>
where State: Copy + Eq + Hash + Send + Sync,
{ /* private fields */ }

Implementations

Source

impl<State> UserBasisBuilder<State>
where State: Copy + Eq + Hash + Send + Sync + 'static,

pub fn states(self, states: impl IntoIterator<Item = State>) -> Self

pub fn deferred_states<F>(self, factory: F) -> Self
where F: Fn() -> Result<Vec<State>> + Send + Sync + 'static,

Defer potentially expensive state enumeration until materialize or build is called.

pub fn operator<F>(self, name: char, action: F) -> Self
where F: Fn(State, usize) -> Result<Option<(State, Complex64)>> + Send + Sync + 'static,

pub fn branching_operator<F>(self, name: char, action: F) -> Self
where F: Fn(State, usize) -> Result<Vec<(State, Complex64)>> + Send + Sync + 'static,

Register a local action with more than one nonzero destination.

pub fn build(self) -> Result<UserBasis<State>>

pub fn materialize(self) -> Result<UserBasis<State>>

Source

impl UserBasisBuilder<u128>

pub fn state_filter<F>(self, keep: F) -> Result<Self>
where F: Fn(u128) -> bool,

pub fn state_filter_parallel<F>(self, keep: F) -> Result<Self>
where F: Fn(u128) -> bool + Sync,

Deterministically enumerate a filtered binary state space in parallel.