thermal_observable_contraction

Function thermal_observable_contraction 

pub fn thermal_observable_contraction(
    method: ThermalLanczosMethod,
    eigenvalues: &[f64],
    eigenvectors: &[Vec<f64>],
    observables: &[ProjectedThermalObservable],
    inverse_temperatures: &[f64],
) -> Result<ThermalObservableIteration>
Contract projected observables with an existing Lanczos Ritz eigensystem.

eigenvectors are column-oriented, matching LanczosRitzDecomposition. This function is useful at language boundaries where an observable may be callback-owned but its action can still be projected into the Krylov basis.