#[non_exhaustive]pub struct EvolutionOptions {
pub times: Vec<f64>,
pub krylov_dimension: usize,
pub tolerance: f64,
pub max_substeps: usize,
pub hamiltonian: bool,
}Expand description
Time grid and adaptive Krylov controls for state evolution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.times: Vec<f64>Finite nondecreasing output times measured from the initial state.
krylov_dimension: usizeMaximum dimension of each Krylov projection.
tolerance: f64Local error tolerance.
max_substeps: usizeMaximum accepted and rejected trial intervals.
hamiltonian: boolInterpret the generator as H and apply exp(-i H t) when true.
Implementations
Sourceimpl EvolutionOptions
impl EvolutionOptions
Sourcepub fn new(times: impl Into<Vec<f64>>) -> Self
pub fn new(times: impl Into<Vec<f64>>) -> Self
Construct Hamiltonian evolution controls on the supplied output grid.
Sourcepub fn with_krylov_dimension(self, dimension: usize) -> Self
pub fn with_krylov_dimension(self, dimension: usize) -> Self
Set the maximum dimension of each Krylov projection.
Sourcepub fn with_tolerance(self, tolerance: f64) -> Self
pub fn with_tolerance(self, tolerance: f64) -> Self
Set the local error tolerance.
Sourcepub fn with_max_substeps(self, max_substeps: usize) -> Self
pub fn with_max_substeps(self, max_substeps: usize) -> Self
Set the maximum accepted and rejected trial intervals.
Sourcepub fn with_hamiltonian(self, hamiltonian: bool) -> Self
pub fn with_hamiltonian(self, hamiltonian: bool) -> Self
Select Hamiltonian (exp(-iHt)) or direct-generator evolution.