pub struct LanczosRitzDecomposition {
pub decomposition: LanczosDecomposition,
pub eigenvalues: Vec<f64>,
pub eigenvectors: Vec<Vec<f64>>,
}Fields
decomposition: LanczosDecompositioneigenvalues: Vec<f64>eigenvectors: Vec<Vec<f64>>Column-oriented eigenvectors of the real symmetric tridiagonal matrix.
Implementations
Sourceimpl LanczosRitzDecomposition
impl LanczosRitzDecomposition
Sourceimpl LanczosRitzDecomposition
impl LanczosRitzDecomposition
Sourcepub fn project_thermal_observables(
&self,
observables: &[(String, &dyn LinearOperator)],
method: ThermalLanczosMethod,
) -> Result<Vec<ProjectedThermalObservable>>
pub fn project_thermal_observables( &self, observables: &[(String, &dyn LinearOperator)], method: ThermalLanczosMethod, ) -> Result<Vec<ProjectedThermalObservable>>
Apply observables to the stored Krylov basis and return only the projected data required by the selected thermal contraction.
pub fn thermal_observable_iteration( &self, method: ThermalLanczosMethod, observables: &[(String, &dyn LinearOperator)], inverse_temperatures: &[f64], ) -> Result<ThermalObservableIteration>