pub fn partial_trace_sector_density<State>(
density: &[Complex64],
basis_states: &[State],
total_sites: usize,
retained_sites: &[usize],
noncommuting_groups: &[NoncommutingGroup],
) -> Result<Vec<Complex64>>where
State: BinaryState,Expand description
Reduced density matrix of a mixed state stored in an arbitrary binary sector basis.
Only pairs with the same environment key are visited. The input remains a dense matrix in the selected sector, but no unrestricted parent density matrix is formed.