pub struct EvolutionDiagnostics {
pub lanczos_projections: usize,
pub matrix_vector_products: usize,
pub real_lanczos_projections: usize,
pub real_matrix_vector_products: usize,
pub accepted_substeps: usize,
pub rejected_trial_intervals: usize,
pub maximum_estimated_error: f64,
}Expand description
Algorithmic work performed by Hermitian Krylov time evolution.
Wall time depends on the host and sparse backend. These counters expose the
portable cost drivers needed by verification and performance-regression
suites without changing the existing evolve return contract.
Fields
lanczos_projections: usizematrix_vector_products: usizereal_lanczos_projections: usizereal_matrix_vector_products: usizeaccepted_substeps: usizerejected_trial_intervals: usizemaximum_estimated_error: f64Trait Implementations
Sourceimpl Clone for EvolutionDiagnostics
impl Clone for EvolutionDiagnostics
Sourcefn clone(&self) -> EvolutionDiagnostics
fn clone(&self) -> EvolutionDiagnostics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvolutionDiagnostics
impl Debug for EvolutionDiagnostics
Sourceimpl Default for EvolutionDiagnostics
impl Default for EvolutionDiagnostics
Sourcefn default() -> EvolutionDiagnostics
fn default() -> EvolutionDiagnostics
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for EvolutionDiagnostics
impl PartialEq for EvolutionDiagnostics
Sourcefn eq(&self, other: &EvolutionDiagnostics) -> bool
fn eq(&self, other: &EvolutionDiagnostics) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EvolutionDiagnostics